# load ZIGP package
library(ZIGP)

# read data
data.patent <- read.table("<enter path>/patent.txt", header=TRUE)
attach(data.patent)

# compose design matrices
# full pool of covariates
X <- cbind(Intercept, LN.COV, BREADTH, SQRT.EMP, INV.RDP, RDE1,
     RDE2, RDE3, RDmiss, CHEM.PHA, ELEC.TEL.OTHER, YEAR,
     LN.COV.BREADTH, CHEM.PHA.LN.COV, CHEM.PHA.SQRT.EMP,
     RDmiss.CHEM.PHA)
W <- cbind(Intercept, ENGINEER, CAR.SUPP.OTHER, MED.BIOT, YEAR, BREADTH.49.72,
     EMP.11291, RDE.63)
Z <- cbind(Intercept, BREADTH.06, EMP.2023.11291, RDP.34, CHEM.PHA.ENGIN)

# run model
wald.test(Y, X, W, Z, Offset=E, init=T)

#
#    X1                  X2          X3         X4        X5       X6    X7
#1                             Estimate Std. Error   z value Pr(>|z|)      
#2            MU REGRESSION                                                
#3   b0           Intercept    -1.02295    0.12577  -8.13379  0.00000   ***
#4   b1              LN.COV     0.02548    0.03688   0.69079  0.48969      
#5   b2             BREADTH     0.04672    0.03226   1.44825  0.14755      
#6   b3            SQRT.EMP    -0.39590    0.02832 -13.97814  0.00000   ***
#7   b4             INV.RDP    -0.19475    0.16643  -1.17016  0.24193      
#8   b5                RDE1     0.14672    0.03757   3.90529  0.00009   ***
#9   b6                RDE2    -0.05022    0.03134  -1.60238  0.10907      
#10  b7                RDE3     0.02980    0.03341   0.89184  0.37248      
#11  b8              RDmiss     0.24717    0.35355   0.69912  0.48448      
#12  b9            CHEM.PHA    -0.24497    0.12953  -1.89117  0.05860     .
#13 b10      ELEC.TEL.OTHER     0.28926    0.07211   4.01162  0.00006   ***
#14 b11                YEAR     0.03892    0.03385   1.14974  0.25025      
#15 b12      LN.COV.BREADTH    -0.11596    0.03517  -3.29711  0.00098   ***
#16 b13     CHEM.PHA.LN.COV     0.01896    0.14339   0.13221  0.89482      
#17 b14   CHEM.PHA.SQRT.EMP    -0.05774    0.14051  -0.41094  0.68111      
#18 b15     RDmiss.CHEM.PHA    -0.32894    0.32623  -1.00829  0.31332      
#19          PHI REGRESSION                                                
#20  a0           Intercept     1.90608    0.11262  16.92425  0.00000   ***
#21  a1            ENGINEER    -0.41940    0.18317  -2.28968  0.02204     *
#22  a2      CAR.SUPP.OTHER    -0.51848    0.10458  -4.95764  0.00000   ***
#23  a3            MED.BIOT     0.02762    0.18901   0.14614  0.88381      
#24  a4                YEAR     0.21290    0.05299   4.01743  0.00006   ***
#25  a5       BREADTH.49.72     0.11167    0.09180   1.21644  0.22382      
#26  a6           EMP.11291    -0.55070    0.11157  -4.93594  0.00000   ***
#27  a7              RDE.63    -0.35474    0.10496  -3.37992  0.00073   ***
#28        OMEGA REGRESSION                                                
#29  g0           Intercept    -4.20896    0.54882  -7.66906  0.00000   ***
#30  g1          BREADTH.06     1.90793    0.55591   3.43209  0.00060   ***
#31  g2      EMP.2023.11291     0.70125    0.44246   1.58490  0.11299      
#32  g3              RDP.34    -1.20358    0.53664  -2.24280  0.02491     *
#33  g4      CHEM.PHA.ENGIN     1.10458    0.42128   2.62196  0.00874    **
#34                                                                        
#35        Signif. codes: 0 `***' 0.001 `**'  0.01 `*'  0.05 `.'  0.1 ` ' 1
#36              Iterations                    140                         
#37          Log Likelihood                -3239.2                         
#38     Pearson Chi Squared                   44.5                         
#39                     AIC                   6536                         
#40                Range Mu                   0.16    543.71               
#41               Range Phi                   2.17     11.70               
#42             Range Omega                   0.00      0.38               




# reduced set of covariates
X <- cbind(Intercept, LN.COV, BREADTH, SQRT.EMP, INV.RDP, RDE1,
     CHEM.PHA, ELEC.TEL.OTHER, LN.COV.BREADTH)
W <- cbind(Intercept, ENGINEER, CAR.SUPP.OTHER, YEAR, EMP.11291, RDE.63)
Z <- cbind(Intercept, BREADTH.06, RDP.34, CHEM.PHA.ENGIN)

# run model
wald.test(Y, X, W, Z, Offset=E, init=T)

#   X1                  X2          X3         X4        X5       X6    X7
#1                            Estimate Std. Error   z value Pr(>|z|)      
#2           MU REGRESSION                                                
#3  b0           Intercept    -0.95096    0.05922 -16.05884  0.00000   ***
#4  b1              LN.COV     0.03114    0.03579   0.87008  0.38425      
#5  b2             BREADTH     0.04110    0.03168   1.29718  0.19457      
#6  b3            SQRT.EMP    -0.39412    0.02713 -14.52940  0.00000   ***
#7  b4             INV.RDP    -0.12328    0.03307  -3.72832  0.00019   ***
#8  b5                RDE1     0.12431    0.03311   3.75447  0.00017   ***
#9  b6            CHEM.PHA    -0.27222    0.09892  -2.75191  0.00592    **
#10 b7      ELEC.TEL.OTHER     0.30619    0.06635   4.61511  0.00000   ***
#11 b8      LN.COV.BREADTH    -0.10376    0.03442  -3.01478  0.00257    **
#12         PHI REGRESSION                                                
#13 a0           Intercept     1.96707    0.08550  23.00606  0.00000   ***
#14 a1            ENGINEER    -0.42542    0.17050  -2.49521  0.01259     *
#15 a2      CAR.SUPP.OTHER    -0.48764    0.09624  -5.06692  0.00000   ***
#16 a3                YEAR     0.16141    0.04224   3.82133  0.00013   ***
#17 a4           EMP.11291    -0.58529    0.10254  -5.70781  0.00000   ***
#18 a5              RDE.63    -0.30467    0.09650  -3.15730  0.00159    **
#19       OMEGA REGRESSION                                                
#20 g0           Intercept    -4.27886    0.58534  -7.30999  0.00000   ***
#21 g1          BREADTH.06     2.26872    0.57688   3.93276  0.00008   ***
#22 g2              RDP.34    -1.23958    0.52122  -2.37823  0.01740     *
#23 g3      CHEM.PHA.ENGIN     1.08450    0.41284   2.62691  0.00862    **
#24                                                                       
#25       Signif. codes: 0 `***' 0.001 `**'  0.01 `*'  0.05 `.'  0.1 ` ' 1
#26             Iterations                     95                         
#27         Log Likelihood                -3245.2                         
#28    Pearson Chi Squared                   42.6                         
#29                    AIC                   6528                         
#30               Range Mu                   0.18    446.35               
#31              Range Phi                   2.41     10.15               
#32            Range Omega                   0.00      0.28               
